@@ -1,13 +1,13 @@
 package RDF::vCard;
 
 use 5.008;
-use common::sense;
+use strict;
 
 use RDF::vCard::Entity;
 use RDF::vCard::Exporter;
 use RDF::vCard::Importer;
 
-our $VERSION = '0.008';
+our $VERSION = '0.009';
 
 our $WITH_XML;
 BEGIN {
