@@ -1,10 +1,11 @@
 package RDF::vCard::Line;
 
 use 5.008;
-use common::sense;
+use strict;
 
+use Encode;
 use MIME::Base64;
-use RDF::TrineShortcuts ':all';
+use RDF::TrineX::Functions -shortcuts;
 use URI::data;
 
 sub V    { return 'http://www.w3.org/2006/vcard/ns#' . shift; }
@@ -15,7 +16,7 @@ sub XSD  { return 'http://www.w3.org/2001/XMLSchema#' . shift; }
 use namespace::clean;
 
 use overload '""' => \&to_string;
-our $VERSION = '0.006';
+our $VERSION = '0.009';
 
 sub new
 {
@@ -209,6 +210,12 @@ sub value_node
 		return rdf_resource("$uri");
 	}
 
+	if (defined $self->type_parameters->{LANG})
+	{
+		return rdf_literal($self->value_to_string,
+			lang => $self->type_parameters->{LANG});
+	}
+
 	return rdf_literal($self->value_to_string);
 }
 
@@ -582,7 +589,13 @@ That's why it's sometimes useful to have a normalised version of it...
 =item * C<< nvalue() >>
 
 Returns a normalised version of the arrayref for the value. It will always
-be an arrayref of arrayrefs.
+be an arrayref of arrayrefs. For example:
+
+  [
+    ['Smith'],
+    ['John'],
+    ['Edward', 'James'],
+  ]
 
 =item * C<< value_node() >>
 
